pub enum IFeeManagerErrors {
OnlyValidator(OnlyValidator),
OnlySystemContract(OnlySystemContract),
InvalidToken(InvalidToken),
PoolDoesNotExist(PoolDoesNotExist),
InsufficientFeeTokenBalance(InsufficientFeeTokenBalance),
InternalError(InternalError),
CannotChangeWithinBlock(CannotChangeWithinBlock),
CannotChangeWithPendingFees(CannotChangeWithPendingFees),
TokenPolicyForbids(TokenPolicyForbids),
}Expand description
Container for all the IFeeManager custom errors.
Variants
OnlyValidator(OnlyValidator)
OnlySystemContract(OnlySystemContract)
InvalidToken(InvalidToken)
PoolDoesNotExist(PoolDoesNotExist)
InsufficientFeeTokenBalance(InsufficientFeeTokenBalance)
InternalError(InternalError)
CannotChangeWithinBlock(CannotChangeWithinBlock)
CannotChangeWithPendingFees(CannotChangeWithPendingFees)
TokenPolicyForbids(TokenPolicyForbids)
Implementations
Sourceimpl IFeeManagerErrors
impl IFeeManagerErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl FeeManagerError
impl FeeManagerError
Sourcepub const fn only_validator() -> Self
pub const fn only_validator() -> Self
Creates an error for only validator access.
Sourcepub const fn only_system_contract() -> Self
pub const fn only_system_contract() -> Self
Creates an error for only system contract access.
Sourcepub const fn invalid_token() -> Self
pub const fn invalid_token() -> Self
Creates an error for invalid token.
Sourcepub const fn pool_does_not_exist() -> Self
pub const fn pool_does_not_exist() -> Self
Creates an error when pool does not exist.
Sourcepub const fn insufficient_fee_token_balance() -> Self
pub const fn insufficient_fee_token_balance() -> Self
Creates an error for insufficient fee token balance.
Sourcepub const fn cannot_change_within_block() -> Self
pub const fn cannot_change_within_block() -> Self
Creates an error for cannot change within block.
Sourcepub const fn cannot_change_with_pending_fees() -> Self
pub const fn cannot_change_with_pending_fees() -> Self
Creates an error for cannot change with pending fees.
Sourcepub const fn token_policy_forbids() -> Self
pub const fn token_policy_forbids() -> Self
Creates an error for token policy forbids.