pub struct IFeeManagerInstance<P, N = Ethereum> {
address: Address,
provider: P,
_network: PhantomData<N>,
}Expand description
A IFeeManager instance.
Contains type-safe methods for interacting with an on-chain instance of the
IFeeManager contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Fields
address: Addressprovider: P_network: PhantomData<N>Implementations
Sourceimpl<P: Provider<N>, N: Network> IFeeManagerInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> IFeeManagerInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain IFeeManager contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> IFeeManagerInstance<&P, N>
impl<P: Clone, N> IFeeManagerInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> IFeeManagerInstance<P, N>
pub fn with_cloned_provider(self) -> IFeeManagerInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> IFeeManagerInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> IFeeManagerInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn userTokens(&self, user: Address) -> SolCallBuilder<&P, userTokensCall, N>
pub fn userTokens(&self, user: Address) -> SolCallBuilder<&P, userTokensCall, N>
Creates a new call builder for the [userTokens] function.
Sourcepub fn validatorTokens(
&self,
validator: Address,
) -> SolCallBuilder<&P, validatorTokensCall, N>
pub fn validatorTokens( &self, validator: Address, ) -> SolCallBuilder<&P, validatorTokensCall, N>
Creates a new call builder for the [validatorTokens] function.
Sourcepub fn setUserToken(
&self,
token: Address,
) -> SolCallBuilder<&P, setUserTokenCall, N>
pub fn setUserToken( &self, token: Address, ) -> SolCallBuilder<&P, setUserTokenCall, N>
Creates a new call builder for the [setUserToken] function.
Sourcepub fn setValidatorToken(
&self,
token: Address,
) -> SolCallBuilder<&P, setValidatorTokenCall, N>
pub fn setValidatorToken( &self, token: Address, ) -> SolCallBuilder<&P, setValidatorTokenCall, N>
Creates a new call builder for the [setValidatorToken] function.
Sourcepub fn distributeFees(
&self,
validator: Address,
token: Address,
) -> SolCallBuilder<&P, distributeFeesCall, N>
pub fn distributeFees( &self, validator: Address, token: Address, ) -> SolCallBuilder<&P, distributeFeesCall, N>
Creates a new call builder for the [distributeFees] function.
Sourcepub fn collectedFees(
&self,
validator: Address,
token: Address,
) -> SolCallBuilder<&P, collectedFeesCall, N>
pub fn collectedFees( &self, validator: Address, token: Address, ) -> SolCallBuilder<&P, collectedFeesCall, N>
Creates a new call builder for the [collectedFees] function.
Sourceimpl<P: Provider<N>, N: Network> IFeeManagerInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> IFeeManagerInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn UserTokenSet_filter(&self) -> Event<&P, UserTokenSet, N>
pub fn UserTokenSet_filter(&self) -> Event<&P, UserTokenSet, N>
Creates a new event filter for the UserTokenSet event.
Sourcepub fn ValidatorTokenSet_filter(&self) -> Event<&P, ValidatorTokenSet, N>
pub fn ValidatorTokenSet_filter(&self) -> Event<&P, ValidatorTokenSet, N>
Creates a new event filter for the ValidatorTokenSet event.
Sourcepub fn FeesDistributed_filter(&self) -> Event<&P, FeesDistributed, N>
pub fn FeesDistributed_filter(&self) -> Event<&P, FeesDistributed, N>
Creates a new event filter for the FeesDistributed event.